@@ -1,4 +1,4 @@
 class BaseComponent:
     @staticmethod
     def boom() -> None:
-        print("👾💥👾👾👾")
\ No newline at end of file
+        print("👾💥👾👾👾💥")
